V3MetricBuilder

Struct V3MetricBuilder 

pub struct V3MetricBuilder<'a> { /* private fields */ }
Builder for a single metric within a V3 payload.

Use the setter methods to configure the metric, add points with add_point, then call close to finalize.

Implementations

Source

impl<'a> V3MetricBuilder<'a>

pub fn set_tags<I, S>(&mut self, tags: I)
where I: Iterator<Item = S>, S: AsRef<str>,

Sets the tags for this metric.

Tags should be in “key:value” format.

pub fn set_resources(&mut self, resources: &[(&str, &str)])

Sets the resources for this metric.

Resources are (type, name) pairs, for example, (host, server1).

pub fn set_interval(&mut self, interval: u64)

Sets the interval for this metric (used for rate metrics).

pub fn set_source_type(&mut self, source_type: &str)

Sets the source type name for this metric.

pub fn set_origin( &mut self, product: u32, category: u32, service: u32, no_index: bool, )

Sets the origin metadata for this metric.

pub fn set_unit(&mut self, unit: &str)

Sets the unit for this metric.

pub fn add_point(&mut self, timestamp: i64, value: f64)

Adds a data point to this metric.

pub fn add_sketch( &mut self, timestamp: i64, count: i64, sum: f64, min: f64, max: f64, bin_keys: &[i32], bin_counts: &[u32], )

Adds sketch data for a distribution metric.

For sketches, the summary values (count, sum, min, max) are stored as points, and the bin keys/counts are stored separately.

pub fn close(self)

Finalizes this metric.

This compacts the point values to use the smallest representation that can hold all values without loss.